@@ -49,6 +49,8 @@ class ContentMap(models.Model):
     def save(self, *args, **options):
         self.full_clean()
         super(ContentMap, self).save(*args, **options)
+        for urlmap in self.urlmap_set.all():
+            cache.set(urlmap.cache_key(), None, 5)
 
 
 class URLMapManager(models.Manager):
