@@ -14,11 +14,9 @@
 
 from django.conf import settings
 from django.contrib.sites.models import get_current_site, Site
-from django.contrib.auth.models import AnonymousUser
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.http import Http404, HttpResponse, HttpRequest
 from django.test.client import RequestFactory
-from django_any.contrib import any_user
 from override_settings import override_settings
 from test_extensions import TestCase
 from urlographer import models, tasks, sample_views, utils, views
@@ -36,12 +34,20 @@ class ContentMapTest(TestCase):
             ValidationError, 'Please enter a valid view.', content_map.clean)
 
     def test_save(self):
+        content_map = models.ContentMap.objects.create(
+            view='urlographer.views.route')
+        models.URLMap.objects.create(
+            site=Site.objects.get(id=1), path='/test_path',
+            content_map=content_map)
         # infinite recursion FTW
         mock = mox.Mox()
         mock.StubOutWithMock(models.ContentMap, 'full_clean')
+        mock.StubOutWithMock(models.URLMap, 'cache_key')
+        mock.StubOutWithMock(models.cache, 'set')
         models.ContentMap.full_clean()
+        models.URLMap.cache_key().AndReturn('urlmap_key')
+        models.cache.set('urlmap_key', None, 5)
 
-        content_map = models.ContentMap(view='urlographer.views.route')
         mock.ReplayAll()
         content_map.save()
         mock.VerifyAll()
@@ -436,6 +442,11 @@ class ForceCacheInvalidationTest(TestCase):
     def test_header_not_set(self):
         self.assertFalse(utils.force_cache_invalidation(self.factory.get('/')))
 
+    def test_header_set(self):
+        request = self.factory.get('/')
+        request.META.update({'HTTP_CACHE_CONTROL': 'no-cache'})
+        self.assertTrue(utils.force_cache_invalidation(request))
+
 
 class SitemapTest(TestCase):
     def setUp(self):
